@@ -18,10 +18,10 @@ class ConfigAlgo(Config):
         default=70,
         help_string="max watermark for disk utilization",
     )
-    watermark_min = ParamCreator.create_int_or_none(
-        default=None,
-        help_string="min watermark for disk utilization",
-    )
+    # watermark_min = ParamCreator.create_int_or_none(
+    #    default=None,
+    #    help_string="min watermark for disk utilization",
+    # )
     disregard = ParamCreator.create_list_str(
         default="/",
         help_string="what mount points to disregard",
