@@ -3,7 +3,6 @@ The default group of operations that pyflexebs has
 """
 import logging
 import os
-import subprocess
 import sys
 import time
 
@@ -20,9 +19,13 @@ from pyflexebs.configs import ConfigAlgo, ConfigProxy
 
 import pypathutil.common
 
+from pyflexebs.utils import run_with_logger
+
 GROUP_NAME_DEFAULT = "default"
 GROUP_DESCRIPTION_DEFAULT = "all pyflexebs commands"
 
+TAG_DONT_RESIZE = "dont_resize"
+
 
 def register_group_default():
     """
@@ -52,13 +55,15 @@ def daemon() -> None:
     """
     Run daemon and monitor disk utilization
     """
-    logger = logging.getLogger(__name__)
+    logger = get_logger()
     configure_proxy()
     check_tools()
+    check_root()
     metadata = ec2_metadata.ec2_metadata
     instance_id = metadata.instance_id
     ec2_resource = boto3.resource('ec2', region_name=metadata.region)
     instance = ec2_resource.Instance(instance_id)
+    tags = instance.tags
     ec2_client = boto3.client('ec2', region_name=metadata.region)
 
     volumes = instance.volumes.all()
@@ -75,6 +80,8 @@ def daemon() -> None:
                 continue
             if p.fstype not in ConfigAlgo.file_systems:
                 continue
+            if TAG_DONT_RESIZE in tags:
+                continue
             logger.info("checking {} {} {}".format(
                 p.device,
                 p.mountpoint,
@@ -92,17 +99,6 @@ def daemon() -> None:
                         psutil.disk_usage(p.mountpoint).used,
                     ))
                     enlarge_volume(p, device_to_volume, ec2_client)
-            if ConfigAlgo.watermark_min is not None:
-                if psutil.disk_usage(p.mountpoint).percent <= ConfigAlgo.watermark_min:
-                    logger.info("min watermark detected at disk {} mountpoint {}".format(
-                        p.device,
-                        p.mountpoint,
-                    ))
-                    logger.info("percent is {}, total is {}, used is {}".format(
-                        psutil.disk_usage(p.mountpoint).percent,
-                        psutil.disk_usage(p.mountpoint).total,
-                        psutil.disk_usage(p.mountpoint).used,
-                    ))
         time.sleep(ConfigAlgo.interval)
 
 
@@ -118,7 +114,7 @@ def normalize_device(dev: str) -> str:
 
 
 def enlarge_volume(p, device_to_volume, ec2):
-    logger = logging.getLogger(__name__)
+    logger = get_logger()
     if p.device not in device_to_volume:
         logger.error("Cannot find device [{}]. Not resizing".format(p.device))
         return
@@ -148,17 +144,17 @@ def enlarge_volume(p, device_to_volume, ec2):
     logger.info("doing [{}] extension", format(p.fstype))
     if p.fstype == "ext4":
         if not ConfigAlgo.dryrun:
-            subprocess.check_call([
+            run_with_logger([
                 "resize2fs",
                 p.device,
-            ])
+            ], logger=logger)
     if p.fstype == "xfs":
         if not ConfigAlgo.dryrun:
-            subprocess.check_call([
+            run_with_logger([
                 "xfs_growfs",
                 "-d",
                 p.mountpoint,
-            ])
+            ], logger=logger)
 
 
 @register_endpoint(
@@ -169,7 +165,7 @@ def show_volumes() -> None:
     """
     Show volume information
     """
-    logger = logging.getLogger(__name__)
+    logger = get_logger()
     configure_proxy()
     metadata = ec2_metadata.ec2_metadata
     # check that we have attached an IAM role to the machine
@@ -216,7 +212,7 @@ def show_policies() -> None:
     """
     Show policies that are configured for your role
     """
-    logger = logging.getLogger(__name__)
+    logger = get_logger()
     configure_proxy()
     metadata = ec2_metadata.ec2_metadata
     # check that we have attached an IAM role to the machine
@@ -256,7 +252,7 @@ def check_tools():
     """
     Check that the command line tools we need are available
     """
-    logger = logging.getLogger(__name__)
+    logger = get_logger()
     problems = False
     for app in ["xfs_growfs", "resize2fs"]:
         if pypathutil.common.find_in_standard_path(app) is None:
@@ -264,3 +260,12 @@ def check_tools():
             logger.error("please install executable [{}]".format(app))
     if problems:
         sys.exit(1)
+
+
+def get_logger():
+    return logging.getLogger(pyflexebs.logger_name)
+
+
+def check_root():
+    if not os.geteuid() == 0:
+        sys.exit('Script must be run as root')
